Learn R Programming

hzar (version 0.2-5)

hzar.AIC.hzar.obsDataGroup: Generate an AIC score table.

Description

Calculate the AIC or corrected AIC score table for the given hzar.obsDataGroup object. There will be one score generated for each model associated with this object.

Usage

hzar.AIC.hzar.obsDataGroup(obsDataGroup, label = "AIC", show.count = FALSE, show.param = FALSE) hzar.AICc.hzar.obsDataGroup(obsDataGroup, label = "AICc", show.count = FALSE, show.param = FALSE)

Arguments

obsDataGroup
The hzar.obsDataGroup object for which to generate the score table.
label
The name to use for the score column.
show.count
Include an addition column with a count of the number of free parameters.
show.param
Currently does nothing. Include additional columns with the parameter values of the maximum likelhood model for each score.

Value

A data frame with at least one column, with the label specified above.If the models in the obsDataGroup have names, then the rownames of the data frame are the models' names.If show.count is TRUE, the result will have one additional column with the label "count". For each score this column will have the number of free parameters.

See Also

AIC hzar.AIC.default

Examples

Run this code
##TODO

Run the code above in your browser using DataLab