Learn R Programming

hzar (version 0.2-5)

hzar.dBernoulli.LL: Transformations of Scalar Data into Bernoulli Trials

Description

This method operates on a collection of sampled scalar values and the sample localition site factor. It calculates a score for each "cut" value that can split the samples into unique groups, and either returns those scores, the cut value with the best score, or a table of the frequencies of the sample values that are less than the cut value with the best score.

Usage

hzar.dBernoulli.LL(values, locations, getMax = FALSE, getProbs = FALSE)

Arguments

values
The sample values to use.
locations
The factor grouping sample values by location.
getMax
Should this method return the best cut value?
getProbs
Should this method return the table of frequencies of sample values which are less than the best cut value?

Value

Either a vector of scores, a single cut value, or a table of frequencies of the sample values that are less than the cut value with the best score.

Details

The score for a cut value is the information of learning the location of a sample conditioned on the knowledge of the whether the sample value is greater or less than the cut value. This score indicates how little a cut value distinguishes between localities.

The best scoring cut value is the one that determines the greatest amount of information about the sample location and therefore it is the one with lowest score.

See Also

hzar.doMorphoSets hzar.obsData