Learn R Programming

hzar (version 0.2-5)

hzar.dataGroup.add: Prepare optimizer output for analysis.

Description

Intended to group multiple fits of the same model and the same observation data into a single object. As it works with hzar.fitRequest objects, it is simpler to use than hzar.make.dataGroup.

Usage

hzar.dataGroup.add(dataGroup, fitRequestL = list(), doPar = FALSE) hzar.fit2DataGroup(fitRequest, doPar = FALSE)

Arguments

dataGroup
A single hzar.dataGroup object to update. If fitRequestL is a list of length 0, this argument may also be a list of hzar.fitRequest or hzar.dataGroup objects.
fitRequestL
A hzar.fitRequest or hzar.dataGroup object, a list of such objects, or a deep list of such objects.
fitRequest
A single hzar.fitRequest object. A hzar.dataGroup object may also be used.
doPar
This is argument is passed to hzar.eval.clineLL.

Value

A hzar.dataGroup object.

See Also

hzar.fitRequest hzar.dataGroup hzar.obsDataGroup

Examples

Run this code
data(manakinMolecular);
mknAdaA <-
  hzar.doMolecularData1DPops(manakinMolecular$distance,
                             manakinMolecular$ada.A,
                             manakinMolecular$ada.nSamples);
mknAdaAmodel <-
  hzar.makeCline1DFreq(mknAdaA, scaling="fixed",tails="none");
mknAdaAmodel <-
  hzar.model.addBoxReq(mknAdaAmodel, -30, 600)
mknAdaAmodelFit <-
   hzar.first.fitRequest.old.ML(model=mknAdaAmodel ,
                                mknAdaA,
                                verbose=FALSE);
mknAdaAmodelFit$mcmcParam$chainLength <- 1e3;
mknAdaAmodelFit$mcmcParam$burnin <- 5e2;
mknAdaAFit <- hzar.doFit(mknAdaAmodelFit);
str(hzar.fit2DataGroup(mknAdaAFit));

Run the code above in your browser using DataLab