Learn R Programming

hzar (version 0.2-5)

hzar.doCLTData1DRaw: Create a hzar.obsData object using a table of individual traits.

Description

Create a hzar.obsData object using a table of individual traits.

Usage

hzar.doCLTData1DRaw(distance, traitValue) hzar.doNormalData1DRaw(site.dist, traitSite, traitValue) hzar.mapSiteDist(siteID, distance)

Arguments

distance
The distance of the sampling site. For hzar.doCLTData1DRaw, samples at the same distance are treated as being from the same sampling site.
traitValue
The value of the trait of the individual sampled.
traitSite
The id of site where the individual was found.
site.dist
A named vector mapping site id codes to the distance of the sampling site. The function hzar.mapSiteDist returns a suitable vector.
siteID
The list of id codes associated with the sampling site. This list should be identical in length to distance, each entry must be unique, and the order of the sites referenced must be identical for distance and siteID.

Value

A hzar.obsData object, using the site dinstances and sample means and variances as calculated from the values given.

Details

For hzar.doCLTData1DRaw: If for any locality, there is only a small number of samples taken, warnings will be issued.

If at any locality, the sample variance is 0, a warning is issued, and additional variance is included by estimating the amount of variance ignored due to measurement error.

For hzar.doNormalData1DRaw:

Use the helper function hzar.mapSiteDist to generate site.dist.

The hzar.obsData object created is meant for use with the models constructed using hzar.makeCline1DNormal.

See Also

hzar.obsData