Learn R Programming

hzar (version 0.2-5)

hzar.doFit.multi: Run hzar fit commands on a list of hzar.fitRequest objects

Description

These methods simplify repeated calling of hzar.doFit or hzar.chain.doSeq while taking advantage of %dopar% if requested.

Usage

hzar.doFit.multi(mFitR, doPar = FALSE, inOrder = TRUE) hzar.doChain.multi(mFitR, doPar = FALSE, inOrder = TRUE, ...)

Arguments

mFitR
Provide a list of hzar.fitRequest objects. Use hzar.multiFitRequest to ensure independent seeds and to request independent chains.
doPar
Use %dopar%?
inOrder
Should the results be returned in order? If FALSE, the results are returned in the order of completion. See foreach for more information.
...
Additional arguments to pass to hzar.chain.doSeq

Value

A list of the fitted hzar.fitRequest objects.

See Also

hzar.chain.doSeq hzar.doFit hzar.fitRequest hzar.multiFitRequest %dopar% foreach

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

Run the code above in your browser using DataLab