Learn R Programming

hzar (version 0.2-5)

hzar.eval.clineLL: Calculate the Log Likehoods of the table of parameters provided.

Description

Using the likelihood function and the table of parameter values provided, calculate the likelihood of each row of parameter values.

Usage

hzar.eval.clineLL(data, llFunc, doPar = FALSE)

Arguments

data
A data.frame of the free parameter values. Each column name should match the corresponding parameter name.
llFunc
The log likelihood function to use.
doPar
If TRUE, use %dopar% to iterate over the rows of data.

Value

A data.frame with a single column (model.LL) containing the log likelihoods for each row of data.

See Also

%dopar%