Learn R Programming

hzar (version 0.2-5)

hzar.extract.old.model.gen: Extract information about the clineMetaModel used.

Description

These methods extract the $func and $req methods from the clineMetaModel object used initially. This includes modifications specified by the $parameterTypes item.

Usage

hzar.extract.old.model.gen(fitRequest) hzar.extract.old.model.req(fitRequest)

Arguments

fitRequest
A hzar.fitRequest or a hzar.dataGroup object, or a log likelihood function generated by hzar.

Value

A method which takes the cline parameters as arguments, with the fixed parameters set to default values.The result of that method is boolean for hzar.extract.old.model.req and a function of distance for hzar.extract.old.model.gen.

See Also

hzar.fitRequest hzar.dataGroup clineMetaModel hzar.first.fitRequest.old.ML

Examples

Run this code

data(manakinMolecular);
ASdata <-
  hzar.doMolecularData1DPops(distance=manakinMolecular$distance,
                             pObs=manakinMolecular$ak2.A,
                             nEff=manakinMolecular$ak2.nSamples);
ASclineM <- hzar.makeCline1DFreq(data=ASdata,scaling="none", tails="none");
ASclineM$func;
ASclineM$req;
ASfitA <- hzar.first.fitRequest.old.ML(ASclineM,ASdata)
hzar.extract.old.model.gen(ASfitA)
hzar.extract.old.model.req(ASfitA)

Run the code above in your browser using DataLab