Learn R Programming

hzar (version 0.2-5)

hzar.get.ML.cline: Extract the maximum likelihood cline.

Description

A method for retrieving the fitted cline object (a hzar.cline object) with the maximum likelihood calculated from a fitted cline model (a hzar.dataGroup object or a successful hzar.fitRequest)

Usage

hzar.get.ML.cline(fitRequest)

Arguments

fitRequest
A hzar.dataGroup object or a successful hzar.fitRequest object.

Value

A hzar.cline object.

See Also

hzar.gen.cline