Learn R Programming

hzar (version 0.2-5)

hzar.getCredCut: Get the minimum log likelihood of sufficient credibility.

Description

This method first calculates the cumalitive distribution using the sampled likelihoods and the selects the greatest likelihood that has no more than rejectionPercent of the cumalitive likelihood distribution less than that likelihood.

Usage

hzar.getCredCut(dataGroup, rejectionPercent = 0.05)

Arguments

dataGroup
The hzar.dataGroup object to analyze.
rejectionPercent
The proportion of the cumalitive likelihood distribuition to reject.

Value

The greatest likelihood that has no more than rejectionPercent of the cumalitive likelihood distribution less than that likelihood.

See Also

hzar.dataGroup