Learn R Programming

hzar (version 0.2-5)

hzar.getCredParam: Select a credible subset of a collection of parameters.

Description

Select the subset of the generated samples wuth a likelihood greater that the result of hzar.getCredCut.

Usage

hzar.getCredParam(dataGroup, rejectionPercent = 0.05)

Arguments

dataGroup
The hzar.dataGroup object to analyze.
rejectionPercent
The proportion of the cumalitive likelihood distribuition to reject.

Value

A data.frame of the subset of the generated samples.

See Also

data.frame hzar.getCredCut hzar.dataGroup