Learn R Programming

hzar (version 0.2-5)

hzar.getLLCutParam: Get the region of parameter space close to the maximum likelihood

Description

This function returns the range of parameter values that are within two log likelihood units of the maximum likelihood for a provided character vector of parameters.

Usage

hzar.getLLCutParam(dataGroups, params, cutValue = 2)

Arguments

dataGroups
Either a hzar.dataGroup object, or a list of hzar.dataGroup objects.
params
The parameters to report.
cutValue
The number of log likelihood units to retain.

Value

A data.frame, with 2 columns for each parameter requested, containing the maximum and minimum parameter value within cutValue log likelihood units of the maximum likelihood observed.

See Also

hzar.dataGroup

Examples

Run this code
##TODO

Run the code above in your browser using DataLab