Learn R Programming

hzar (version 0.2-5)

hzar.make.cline: Make a hzar.cline object.

Description

This method creates a hzar.cline object, which describes a cline model with specific parameter values. A log likelihood of the parameters can be assigned to this object. See hzar.gen.cline for a simpler method which just requires the free parameters and a cline model reference.

Usage

hzar.make.cline(free.parameters, parameters, func, LL, isValid = is.function(func))

Arguments

free.parameters
The optimized parameter values for this cline.
parameters
All of the parameter values for this cline.
func
The estimator function for this cline.
LL
The log likelihood of this cline.
isValid
Is this cline valid?

Value

A hzar.cline object. A list with the values:
param.free
See free.parameters above
param.all
See parameters above
clineFunc
See func above
logLike
See LL above
isValid
See isValid above

See Also

hzar.gen.cline