Learn R Programming

hzar (version 0.2-5)

hzar.make.fzCline: Create a hzar.fzCline object

Description

Compile a list of hzar.cline objects into a hzar.fzCline object.

Usage

hzar.make.fzCline(clineList)

Arguments

clineList
A list of clines.

Value

A hzar.fzCline object.
clines
clineList
listFuncInt
A function of a scalar x
fzCline
A function of a numeric series over which clineList is evaluated and the series of maximum and minimum values is returned.