Learn R Programming

hzar (version 0.2-5)

hzar.map.dms2deg: Convert degrees, minutes, seconds, direction to degrees.

Description

This method converts angular measurements from degree, minute, second, direction notation to decimal notation.

Usage

hzar.map.dms2deg(deg, min, sec, dir)

Arguments

deg
The degrees of the angular measurement.
min
The minutes of the angular measurement.
sec
The seconds of the angular measurement.
dir
A character vector indicating the direction of the angular measurement. The case insensitive values "N", "S", "E", "W", "West", "North", "South" and "East" are all valid, any others will result in an error.

Value

A numeric vector of angular measurements.

See Also

hzar.map.latLong.dms hzar.map.latLongSites.dms

Examples

Run this code

hzar.map.dms2deg(9,24,0,"N")

hzar.map.dms2deg(82,33,50,"W")

Run the code above in your browser using DataLab