Learn R Programming

hzar (version 0.2-5)

hzar.meta.init: Observe and Alter the model parameters in the clineMetaModel

Description

This is a collection of methods to get or set attributes of the various model parameters.

Usage

hzar.meta.init(x)
hzar.meta.init(x) <- value
hzar.meta.tune(x)
hzar.meta.tune(x) <- value
hzar.meta.fix(x)
hzar.meta.fix(x) <- value
hzar.meta.lower(x)
hzar.meta.lower(x) <- value
hzar.meta.upper(x)
hzar.meta.upper(x) <- value

Arguments

x
The clineMetaModel to use.
value
The new value or values to set.

Value

  • Returns a list, with one numeric or boolean value per cline parameter.

See Also

clineMetaModel