Learn R Programming

hzar (version 0.2-5)

hzar.model.addBoxReq: Add parameter restriction clauses to cline model

Description

The intent of these methods is to assist the optimizer in exploring the model parameter space by instructing it to ignore models that are not interesting. For example, if all of the sampled localities are in a region 100km wide, then a cline width of 110km is probably not interesting. A cline width of 500km in that scenario would definitely not be interesting at all.

Usage

hzar.model.addBoxReq(meta.model, low, high) hzar.model.addCenterRange(meta.model, low, high) hzar.model.addMaxCenter(meta.model, maxValue) hzar.model.addMinCenter(meta.model, minValue) hzar.model.addMaxDelta(meta.model, maxValue) hzar.model.addMaxWidth(meta.model, maxValue) hzar.model.addMaxVariance(meta.model, maxValue) hzar.model.addNormalBox(meta.model, left, right, bottom,top) hzar.model.addMuRange(meta.model, low, high)

Arguments

meta.model
The clineMetaModel object to modify.
minValue
The smallest value to consider.
maxValue
The greatest value to consider.
left
The leftmost location to consider.
right
The rightmost location to consider.
bottom
The least trait value to consider.
top
The greatest trait value to consider.
low
The leftmost location to consider.
high
The rightmost location to consider.

Value

The modified clineMetaModel object.

Details

The three center methods only add requirements to the center parameter. Likewise, hzar.model.addMaxWidth only adds a maximum width requirement. In constrast, hzar.model.addMaxDelta adds a maximum value requirement to any and all delta parameters present in meta.model.

hzar.model.addBoxReq adds requirements to any and all of the parameters center, width, deltaM, deltaL, and deltaR. The center requirements are the same as calling hzar.model.addCenterRange(meta.model, low, high). The remaining parameters are required to have a maximum value of high-low.

See Also

clineMetaModel

Examples

Run this code
data(manakinMolecular);
mknAdaA <-
  hzar.doMolecularData1DPops(manakinMolecular$distance,
                             manakinMolecular$ada.A,
                             manakinMolecular$ada.nSamples);
mknAdaAmodel <-
  hzar.makeCline1DFreq(mknAdaA, scaling="fixed",tails="none");
mknAdaAmodelB <-
  hzar.model.addBoxReq(mknAdaAmodel,-30,600);
mknAdaAmodel$req;
mknAdaAmodelB$req;

Run the code above in your browser using DataLab