Learn R Programming

hzar (version 0.2-5)

hzar.overPlot.fzCline: Plot a cline region for multiple models and / or loci.

Description

Generates and plots multiple hzar.fzCline objects on the same graph, using shading lines to identify each cline region.

Usage

hzar.overPlot.fzCline(dataGroupSet, fzClineSet = sapply(dataGroupSet, hzar.getCredParamRed, simplify = FALSE), type = "p", fzDens = 8, fzShadeAngle = ((1:length(dataGroupSet)) * 180) %/% (1 + length(dataGroupSet)), ...)

Arguments

dataGroupSet
The list of hzar.dataGroup objects to generate hzar.fzCline objects for plotting.
fzClineSet
The list of hzar.fzCline objects to plot.
type
Passed to hzar.plot.obsData.
fzDens
Density of the shading lines. See polygon.
fzShadeAngle
Angle of the shading lines. See polygon.
...
Additional parameters to pass to hzar.plot.fzCline.

See Also

polygon hzar.getCredParamRed hzar.plot.fzCline hzar.dataGroup