Learn R Programming

hzar (version 0.2-5)

hzar.profile.dataGroup: Generate a likelihood profile for a single parameter

Description

TODO

Usage

hzar.profile.dataGroup(dG, parameter, pVals = NULL, pDivs = NULL, nDiv = 20, appeture = NULL, doPar = FALSE, ...)

Arguments

dG
A hzar.dataGroup of the fitted model
parameter
pVals
pDivs
nDiv
appeture
doPar
...
Arguments to pass to hzar.multiFitRequest

Value

A list of hzar.fitRequest objects to be fitted.

Details

This method does not actually do the fitting of the likelihood profile. See the example for a useable workflow.

References

There is probably a reference to how to do this somewhere...

See Also

hzar.multiFitRequest hzar.dataGroup hzar.fitRequest hzar.doFit.multi hzar.make.obsDataGroup

Examples

Run this code
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

Run the code above in your browser using DataLab