Learn R Programming

hzar (version 0.2-5)

hzar.qScores: Calculate credibility intervals.

Description

Calculate the values with an estimated cumulative likelihood equal to probs for the weighted sampled distribution.

Usage

hzar.qScores(x, wt, probs = c(0, 0.25, 0.5, 0.75, 1)) hzar.qScores.dataGroup(dataGroup, probs = c(0.025, 0.5, 0.975)) hzar.qScores.obsDataGroup(oDG, probs = c(0.025, 0.5, 0.975))

Arguments

x
The series of values to analyze.
wt
The log of the weight applied to each value.
probs
The cumalitve probality values for which to calculate intervals.
dataGroup
The hzar.dataGroup to analyze.
oDG
The hzar.obsDataGroup to analyze.

Value

For hzar.qScores, the values with an estimated cumulative likelihood equal to probs.For both hzar.qScores.dataGroup and hzar.qScores.obsDataGroup, a data.frame with one column "q" for probs, and one additional column for each free parameter with the values returned by hzar.qScores for probs, given the parameter samples and likelihoods.

Details

hzar.qScores.dataGroup generates intervals for all of the free parameters. hzar.qScores.obsDataGroup generates intervals for the cline model with the best AICc score.

See Also

hzar.dataGroup hzar.obsDataGroup hzar.AICc.default

Examples

Run this code
##TODO

Run the code above in your browser using DataLab