Learn R Programming

hzar (version 0.2-5)

manakinLocations: Distance from locality A for each locality.

Description

Distance from locality A for each locality sampled accross the Manakin Cline.

Usage

data(manakinLocations)

Arguments

Format

A data frame with 12 observations on the following 2 variables.
LocalityID
a factor with levels A B C D E F G H I J K L
distance
a numeric vector

Brumfield, R. T., R. W. Jernigan, D. B. McDonald, and M. J. Braun. 2001. Evolutionary implications of divergent clines in an avian (Manacus: Aves) hybrid zone. Evolution 55:2070-2087.

Examples

Run this code
data(manakinLocations)
print(manakinLocations)
## maybe str(manakinLocations) ; plot(manakinLocations) ...

Run the code above in your browser using DataLab