Learn R Programming

hzar (version 0.2-5)

manakinMorphological: Manakin observed Morphological Traits

Description

Morphological Traits observations of individuals sampled from the Manakin Cline.

Usage

data(manakinMorphological)

Arguments

Format

A data frame with 165 observations on the following 7 variables.
Locality
The id code of the locality, a factor with levels A B C D E F G H I J K L
ID
The ID code of the individual sampled
Name
The locality name, a factor with levels Chiriqui_Grande Costa_Rica Quebrada_Pastores Rio_Changuinola Rio_Oeste Rio_Robalo Rio_Sixaola Rio_Teribe Rio_Uyama Soberania Tierra_Oscura Valiente_Peninsula
collar.color
The collar color of the individual sampled
belly.color
The belly color of the individual sampled
epaulet.width
The width of the epaulet of the individual sampled
beard.length
The length of the beard of the individual sampled

Brumfield, R. T., R. W. Jernigan, D. B. McDonald, and M. J. Braun. 2001. Evolutionary implications of divergent clines in an avian (Manacus: Aves) hybrid zone. Evolution 55:2070-2087.

Examples

Run this code
data(manakinMorphological)
str(manakinMorphological)

Run the code above in your browser using DataLab