Usage
hzar.cov.rect(clineLLfunc, param.lower, param.upper, pDiv = 11, random = 0, passCenter = FALSE)
hzar.cov.mcmc(clineLLfunc, mcmcRaw, pDiv = 15, random = 10000, passCenter = FALSE)
Arguments
clineLLfunc
The log likelihood function of the parameters.
param.lower
The minimum boundary of the region of parameter space to consider.
param.upper
The maximum boundary of the region of parameter space to consider.
pDiv
If generating a covariance matrix using a lattice, the lattice
should have this many points on an edge.
random
Use random number of points drawn from a uniform likelihood
space to generate the covariance matrix. If 0, use a lattice to
generate the covariance matrix.
passCenter
Should weighted mean of the parameter space be returned.
mcmcRaw
A mcmc object used to refine the covariance matrix.