hzar.dBernoulli.LL(values, locations, getMax = FALSE, getProbs = FALSE)The best scoring cut value is the one that determines the greatest amount of information about the sample location and therefore it is the one with lowest score.
hzar.doMorphoSets
hzar.obsData