hzar.obsData object using a table of individual traits.
hzar.obsData object using a table of individual
traits.
hzar.doCLTData1DRaw(distance, traitValue)
hzar.doNormalData1DRaw(site.dist, traitSite, traitValue)
hzar.mapSiteDist(siteID, distance)hzar.doCLTData1DRaw, samples at the same distance are treated
as being from the same sampling site.
hzar.mapSiteDist returns a suitable vector.
distance, each entry must be
unique, and the order of the sites referenced must be identical for
distance and siteID.
hzar.obsData object, using the site dinstances and
sample means and variances as calculated from the values given.
hzar.doCLTData1DRaw:
If for any locality, there is only a small number of samples
taken, warnings will be issued.If at any locality, the sample variance is 0, a warning is issued, and additional variance is included by estimating the amount of variance ignored due to measurement error.
For hzar.doNormalData1DRaw:
Use the helper function hzar.mapSiteDist to generate
site.dist.
The hzar.obsData object created is meant for use with
the models constructed using hzar.makeCline1DNormal.
hzar.obsData