hzar.getLLCutParam:
Get the region of parameter space close to the maximum likelihood
Description
This function returns the range of parameter values that are within
two log likelihood units of the maximum likelihood for a provided
character vector of parameters.
A data.frame, with 2 columns for each parameter
requested, containing the maximum and minimum parameter value within
cutValue log likelihood units of the maximum likelihood
observed.