Usage
hzar.make.clineLLfunc.old.ML(param.free.names, param.fixed, param.check.func, meta.cline.func, model.LL, LLrejectedModel = -1e+08)
hzar.make.clineLLfunc.old.bayes(param.free.names, param.fixed, param.check.func, meta.cline.func, model.LL, prior.LL, LLrejectedModel = -1e+08)
Arguments
param.free.names
The names of the free parameters.
param.fixed
A named list of the fixed parameters.
param.check.func
A boolean function of the parameters, which returns true if the
model described is valid.
meta.cline.func
A function of the parameters, which returns a function of distance
estimating frequency.
model.LL
A function which takes one argument and returns a log
likelihood. The argument is a function of distance estimating
frequency.
LLrejectedModel
A finite log likelihood of an invalid model.
prior.LL
A function of the parameters, which returns the log likelihood of
those parameters.