Usage
hzar.make.mcmcParam(chainLength, burnin, verbosity, thin, seedStreamChannel = 1, useSeedStream = TRUE, mersenneSeed = 12345, lecuyerSeed = rep(12345, 6))
Arguments
chainLength
Defines how many generations to run the MCMC process after completing burnin.
burnin
Defines how many states to generate and discard at the begining of
the chain.
verbosity
If 0, output nothing while mcmc process is running.
If positive, print the model state every verbosity generations after burn-in.
thin
Keep only states whose number of generations after burn-in is evenly
divisible by thin.
seedStreamChannel
Set the channel number used in the lecuyer random number generator.
useSeedStream
If TRUE, use the lecuyer random number generator in the MCMC process.
If FALSE, use the mersenne twister random generator in the MCMC process.
mersenneSeed
Sets the seed value for mersenne twister. Expects a numeric of length 1.
lecuyerSeed
Sets the seed value for lecuyer random number generator. Expects a
numeric of length 6.