hzar.map.dms2deg:
Convert degrees, minutes, seconds, direction to degrees.
Description
This method converts angular measurements from degree, minute, second,
direction notation to decimal notation.
Usage
hzar.map.dms2deg(deg, min, sec, dir)
Arguments
deg
The degrees of the angular measurement.
min
The minutes of the angular measurement.
sec
The seconds of the angular measurement.
dir
A character vector indicating the direction of the angular
measurement.
The case insensitive values "N", "S", "E",
"W", "West", "North", "South" and
"East" are all valid, any others will result in an error.