hzar.map.latLongSites:
Generate a table of site locations.
Description
Methods for processing tables of site location:
Generate a table of latitude and longitude of site locations from
either precalculated values or GPS coordinates.
Generate a table of distances from an included site, using a table of
latitude and longitude of site locations.
a=hzar.map.latLongSites(c("Norway"),60.4,11)
b=hzar.map.latLongSites.dms(c("Norway","Sweden"),c("60-24 N 11 E","58 N 15 E"))
hzar.map.distanceFromSite(b,"Norway")