hzar.qScores.getScores:
Generate credibility scores.
Description
Determine the series of weights on a series of intervals from a series
of weighted samples.
Usage
hzar.qScores.getScores(xSeries, dSeries, raw.x, raw.wt)
Arguments
xSeries
Locations to divide integration intervals (must be in ascending order).
dSeries
Widths of locations.
raw.x
Data samples of the distribution.
raw.wt
Log of the weight to apply to each sample.
Value
The weights on the intervals given.